zn.define([
    '../service/ProductService.js'
], function (ProductService) {

    var node_xlsx = require('xlsx');

    return zn.Controller('product',{
        methods: {
            init: function (){
                this.productService = new ProductService(this._store);
            },
            importProductType: {
                method: 'GET/POST',
                argv: {
                    start: 1
                },
                value: function (request, response, chain){
                    var _files = request.$files,
                        _result = [],
                        _start = request.getInt('start') || 2,
                        _vars = JSON.parse(request.getValue('vars')||'{}');

                    this.beginTransaction()
                        .query(zn.sql.select({
                            table: 'zn_plugin_stock_product_type',
                            fields: 'id, zn_title',
                            where: {
                                zn_deleted: 0
                            }
                        })+"select model from zn_plugin_stock_product;")
                        .query('insert data', function (sql, data){
                            var rows = data[0];
                            if(!rows.length){
                                return response.error('系统暂无商品结构'), false;
                            }
                            var serial_numbers = data[1].map(function (item){
                                return item.model
                            });
                            var _titleIds = {},
                                _sqls = [];
                            for(var i = 0, _len = rows.length; i<_len; i++){
                                _titleIds[rows[i].zn_title] = rows[i].id;
                            }

                            zn.each(_files, function (file, key){
                                var _file = request.uploadFile(file),
                                    _worksheet = node_xlsx.readFile(_file.path),
                                    _type_id = 0,
                                    _data = [];
                                Object.keys(_worksheet.Sheets).map((name)=>{
                                    _data = node_xlsx.utils.sheet_to_json(_worksheet.Sheets[name], {
                                        header: 1,
                                        raw: true
                                    });
                                    _type_id = _titleIds[name];

                                    zn.each(_data, function (item, index){
                                        if(index > (_start-1)){
                                            if(item.length){
                                                var _values = { type_id: _type_id, serial_number: 'SN' + zn.util.randomNumbers(10) },
                                                    _value = null,
                                                    _name = null;
                                                for(var i = 0; i < item.length; i++){
                                                    _value = item[i]||'';
                                                    _name = _vars[i]||'';
                                                    if(!_name || !_value){
                                                        continue;
                                                    }
                                                    _values[_name] = _value;
                                                }
                                                _values.model = _values.model.trim();
                                                if(serial_numbers.indexOf(_values.model) == -1){
                                                    _sqls.push(zn.sql.insert({
                                                        table: 'zn_plugin_stock_product',
                                                        values: _values
                                                    }));
                                                }else {
                                                    _values.serial_number = null;
                                                    delete _values.serial_number;
                                                    _sqls.push(zn.sql.update({
                                                        table: 'zn_plugin_stock_product',
                                                        updates: _values,
                                                        where: {
                                                            model: _values.model
                                                        }
                                                    }));
                                                }
                                            }
                                        }
                                    });
                                });
                            });

                            return _sqls.join('');
                        }, function (err, rows){
                            if(err){
                                response.error(err);
                            }else {
                                response.success("导入成功");
                            }
                        }).commit();
                }
            }
        }
    });

});
