zn.define(function () {

    var node_officegen = require('officegen'),
        node_xlsx = require('xlsx');

    return zn.Controller('stock',{
        methods: {
            getWarehouseStock: {
                method: 'GET/POST',
                value: function (request, response, chain){
                    var _data = request.getValue();
                    var _join = request.getValue('join') || 'left',
                        _where = request.getValue('where');
                    _where = zn.extend({}, _where, {
                        'zn_plugin_stock_product_stock.warehouse_id': _data.warehouseId,
                        'zn_plugin_stock_product.type_id': _data.typeId
                        //'0&<': 'zn_plugin_stock_product_stock.count',
                        //'zn_plugin_stock_product.status': '1'
                    });
                    this.query(zn.sql.paging({
                        table: 'zn_plugin_stock_product ' + _join + ' join zn_plugin_stock_product_stock on zn_plugin_stock_product.model = zn_plugin_stock_product_stock.product_model',
                        fields: [
                            'zn_plugin_stock_product.*',
                            'zn_plugin_stock_product_stock.warehouse_id as warehouse_id',
                            'zn_plugin_stock_convert_warehouse(zn_plugin_stock_product_stock.warehouse_id) as warehouse_id_convert',
                            'zn_plugin_stock_product_stock.count as count',
                            'zn_plugin_stock_product_stock.weight as weight'
                        ],
                        where: _where,
                        order: 'zn_plugin_stock_product_stock.count desc, zn_plugin_stock_product.zn_create_time asc',
                        pageIndex: _data.pageIndex,
                        pageSize: _data.pageSize
                    })).then(function(data){
                        response.success(data);
                    }, function (data){
                        response.error(data);
                    });
                }
            },
            exportWarehouseStock: {
                method: 'GET/POST',
                value: function (request, response, chain){
                    var _data = request.getValue();
                    var _where = request.getValue('where');
                    _where = zn.extend({}, _where, {
                        '0&<': 'zn_plugin_stock_product_stock.count'
                        //'zn_plugin_stock_product.status': '1'
                    });
                    if(_data.warehouseId){
                        _where['zn_plugin_stock_product_stock.warehouse_id'] = _data.warehouseId;
                    }
                    if(_data.typeId){
                        _where['zn_plugin_stock_product.type_id'] = _data.typeId;
                    }
                    this.query(zn.sql.select({
                        table: 'zn_plugin_stock_product right join zn_plugin_stock_product_stock on zn_plugin_stock_product.model = zn_plugin_stock_product_stock.product_model',
                        fields: [
                            'zn_plugin_stock_product.zn_title as zn_title',
                            'zn_plugin_stock_product.model as model',
                            'zn_plugin_stock_convert_warehouse(zn_plugin_stock_product_stock.warehouse_id) as warehouse_id_convert',
                            'zn_plugin_stock_product_stock.count as count'
                        ],
                        where: _where,
                        order: 'zn_plugin_stock_product_stock.count desc, zn_plugin_stock_product.zn_create_time desc'
                    })).then(function(data){
                        var _xlsx = node_officegen('xlsx'),
                            _sheet0 = _xlsx.makeNewSheet();
                            _sheet0.name = "商品库存";
                            _sheet0.data[0] = [
                                '商品名称', '型号', '数量', '仓库'
                            ];
                            var _count = 0;
                            data.forEach(function (item){
                                _count += item.count;
                                _sheet0.data.push([
                                    item.zn_title,
                                    item.model,
                                    item.count,
                                    item.warehouse_id_convert
                                ]);
                            });
                            _sheet0.data.push(["汇总： ", '', _count]);
                            response.writeHead(200, {
                                "Content-Type": "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
                                'Content-disposition': 'attachment; filename=' + encodeURI("淳睿商品库存") + '.xlsx'
                            });
                            _xlsx.generate(response._serverResponse);
                    }, function (data){
                        response.error(data);
                    });
                }
            }
        }
    });

});
