var React = require('react');
module.exports = React.createClass({
	getDefaultProps: function () {
		return {
			model: 'ZNPluginStockWarehouse'
		};
	},
	getInitialState: function () {
		return {
			data: zn.store.post('/zn.plugin.admin/model/paging', {
				model: this.props.model
			}),
			items: [
				{ title: '仓库名称', name: 'zn_title', width: 140, filter: { type: 'Input', opts: ['like'] } },
				{ title: '库存类型', name: 'stock_actions', width: 140 },
				{ title: '仓库类型', name: 'warehouse_type', width: 140 },
				{ title: '省', name: 'province', width: 100, filter: { type: 'Input', opts: ['like'] } },
				{ title: '城市', name: 'city', width: 100, filter: { type: 'Input', opts: ['like'] } },
				{ title: '地址', name: 'address', width: 360, filter: { type: 'Input', opts: ['like'] } },
				{ title: '管理员', name: 'admin', width: 100, filter: { type: 'Input', opts: ['like'] } },
				{ title: '电话', name: 'admin_phone', width: 100, filter: { type: 'Input', opts: ['like'] } },
				{ title: '手机号', name: 'admin_telephone', width: 100, filter: { type: 'Input', opts: ['like'] } },
				{ title: '邮箱', name: 'admin_email', width: 100, filter: { type: 'Input', opts: ['like'] } },
				{ title: '说明', name: 'zn_note' }
			],
			formItems: [
				{ title: '仓库名称', name: 'zn_title', type: 'Input', required: true, error: '用户名必填项!' },
				{ title: '仓库类型', name: 'warehouse_type', type: 'Radio', data: [{ text: '自有仓', value: 'self' }, { text: '供应商仓', value: 'supplier' }, { text: '客户仓', value: 'customer' }] },
				{ title: '库存类型', name: 'stock_actions', type: 'CheckboxGroup', data: [{ text: '出库', value: 'out' }, { text: '入库', value: 'in' }, { text: '调拨', value: 'allocate' }] },
				{ title: '省', name: 'province', type: 'Input' },
				{ title: '城市', name: 'city', type: 'Input' },
				{ title: '地址', name: 'address', type: 'Input' },
				{ title: '管理员', name: 'admin', type: 'Input' },
				{ title: '电话', name: 'admin_phone', type: 'Input' },
				{ title: '手机号', name: 'admin_telephone', type: 'Input' },
				{ title: '邮箱', name: 'admin_email', type: 'Input' },
				{ title: '说明', name: 'zn_note', type: 'Textarea' }
			],
			toolbarItems: [
				{ text: '添加', method: '__addItem', icon: 'fa-plus', style: { marginRight: 5 } },
				{ text: '删除', method: '__removeItems', status: 'danger', icon: 'fa-remove', style: { marginRight: 5 } }
			]
		}
	},
	__doSuccess: function (){
		this.state.data.refresh();
	},
	__addItem: function (){
		zn.dialog({
			title: '新增',
			content: <zn.react.Form
				action='/zn.plugin.admin/model/insert'
				merge='values'
				exts={{ model: this.props.model }}
				onSubmitSuccess={this.__doSuccess}
				items={this.state.formItems} />
		});
	},
	__updateItem: function (data){
		zn.dialog({
			title: '更新',
			content: <zn.react.Form
				merge="updates"
				action='/zn.plugin.admin/model/update'
				exts={{ model: this.props.model, where: {id: data.id} }}
				value={data}
				onSubmitSuccess={this.__doSuccess}
				items={this.state.formItems} />
		});
	},
	__removeItems: function (){
		var _self = this,
			_values = this.refs.table.getValue();
		if(_values && _values.length){
			zn.confirm('确认删除这' + _values.length + '个数据吗？', '提示', function () {
				zn.http.post('/zn.plugin.admin/model/delete', {
					model: this.props.model,
					where: "id in (" + _values.join(',') + ")"
				}).then(function (data){
					if(data.status==200){
						zn.toast.success('删除成功');
						_self.state.data.refresh();
					}else {
						zn.toast.error('调用失败: ' + data.result);
					}
				}, function (){
					zn.toast.error('服务器错误: 删除失败');
				});
			}.bind(this));
		}else {
			zn.toast.warning('请先选择要删除的数据');
		}
	},
	__onToolbarClick: function (item){
		this[item.method] && this[item.method]();
	},
	__onTableColumnRender: function (rowIndex, columnIndex, data, item, value){
		switch (item.name) {
			case 'zn_title':
				return <div><i onClick={()=>this.__updateItem(data)} className="fa fa-edit zr-padding-3" /><a href={'#'+zn.react.session.fixPath('/znpluginstock.ProductStock')+'?warehouse=' + data.id}>【{data.id}】{value}</a></div>;
			case 'stock_actions':
				return <div className="actions">
					{
						value.split(',').map(function (_value){
							if(_value=='in'){
								return <span className="zr-tag primary"><i className="fa fa-sign-in" />入仓</span>;
							}
							if(_value=='out'){
								return <span className="zr-tag danger"><i className="fa fa-sign-out" />出仓</span>;
							}
							if(_value=='allocate'){
								return <span className="zr-tag orangle"><i className="fa fa-exchange" />调拨</span>;
							}
						})
					}
				</div>;
			case 'warehouse_type':
				if(value=='self'){
					return <span className="zr-tag primary"><i className="fa fa-institution" />自有仓</span>
				}
				if(value=='supplier'){
					return <span className="zr-tag orangle"><i className="fa fa-address-book-o" />供应商仓</span>
				}
				if(value=='customer'){
					return <span className="zr-tag danger"><i className="fa fa-vcard-o" />客户仓</span>
				}
		}
		return value;
	},
	render:function(){
		return (
			<zn.react.Page title="仓库管理" toolbarItems={this.state.toolbarItems} onToolbarClick={this.__onToolbarClick}>
				<zn.react.PagerView
					ref="table"
					view="Table"
					style={{backgroundColor: '#FFF'}}
					enableFilter={true}
					checkbox={50}
					showHeader={true}
					columnRender={this.__onTableColumnRender}
					data={this.state.data}
					items={this.state.items}/>
			</zn.react.Page>
		);
	}
});
